@@ -161,6 +161,13 @@ class ClBuilderImageAction(Action):
               'method': 'Builder.applyTemplates(cl_builder_target,'
                         'False,False,None)',
               },
+             {'name': 'container_data',
+              'condition': lambda Get: Get('cl_builder_container_set') == 'on'
+              },
+             {'name': 'container_data:filecap',
+              'message': __("Prepare file capabilities"),
+              'method': 'Builder.save_file_capabilities()',
+              },
              {'name': 'squash_action',
               'method': 'Builder.set_builder_action("%s")' % Actions.ImageIso,
               },
@@ -187,9 +194,6 @@ class ClBuilderImageAction(Action):
                         'cl_builder_image_filename)',
               'condition': lambda Get: Get('cl_builder_container_set') == 'off'
               },
-             {'name': 'container_data',
-              'condition': lambda Get: Get('cl_builder_container_set') == 'on'
-              },
              {'name': 'container_data:prepare_container_data',
               'message': __('Preparing container meta data'),
               'method': 'Builder.prepare_container_data('
@@ -199,6 +203,9 @@ class ClBuilderImageAction(Action):
               'method': 'Builder.pack_container_data('
                         'cl_builder_container_data_path,cl_builder_image)',
               },
+             {'name': 'container_data:clear_filecap',
+              'method': 'Builder.clear_file_capabilities()',
+              },
              {'name': 'pack_container_data:digest_container_data',
               'message': __('Calculating SHA256 checksum'),
               'method': 'Builder.create_digest_container(cl_builder_image)',
